package com.zkqy.web.controller.dragForm;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.zkqy.common.annotation.Anonymous;
import com.zkqy.common.annotation.Log;
import com.zkqy.common.core.controller.BaseController;
import com.zkqy.common.core.domain.AjaxResult;
import com.zkqy.common.core.page.TableDataInfo;
import com.zkqy.common.enums.BusinessType;
import com.zkqy.common.utils.poi.ExcelUtil;
import com.zkqy.system.entity.DragTree;
import com.zkqy.system.service.IDragTreeService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;


/**
 * 拖拽树结构Controller
 * 
 * @author hmc
 * @date 2025-03-05
 */
@RestController
@RequestMapping("/dragTree/tree")
public class DragTreeController extends BaseController
{

    @Autowired
    private IDragTreeService dragTreeService;

    /**
     * 查询拖拽树结构列表
     */
//    @PreAuthorize("@ss.hasPermi('dragTree:tree:list')")
    @GetMapping("/list")
    public TableDataInfo list(DragTree dragTree)
    {
        startPage();
        List<DragTree> list = dragTreeService.selectDragTreeList(dragTree);
        return getDataTable(list);
    }

    /**
     * 导出拖拽树结构列表
     */
//    @PreAuthorize("@ss.hasPermi('dragTree:tree:export')")
    @Log(title = "拖拽树结构", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DragTree dragTree)
    {
        List<DragTree> list = dragTreeService.selectDragTreeList(dragTree);
        ExcelUtil<DragTree> util = new ExcelUtil<DragTree>(DragTree.class);
        util.exportExcel(response, list, "拖拽树结构数据");
    }


    /**
     * 获取拖拽树结构详细信息
     */
//    @PreAuthorize("@ss.hasPermi('dragTree:tree:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(dragTreeService.selectDragTreeById(id));
    }

    /**
     * 新增拖拽树结构
     */
//    @PreAuthorize("@ss.hasPermi('dragTree:tree:add')")
    @Anonymous
    @Log(title = "拖拽树结构", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DragTree dragTree)
    {
        return toAjax(dragTreeService.insertDragTree(dragTree));
    }

    /**
     * 修改拖拽树结构
     */
//    @PreAuthorize("@ss.hasPermi('dragTree:tree:edit')")
    @Log(title = "拖拽树结构", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DragTree dragTree)
    {
        return toAjax(dragTreeService.updateDragTree(dragTree));
    }


    /**
     * 删除拖拽树结构
     */
//    @PreAuthorize("@ss.hasPermi('dragTree:tree:remove')")
    @Log(title = "拖拽树结构", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(dragTreeService.deleteDragTreeByIds(ids));
    }
}
